﻿using System;
using Android.App;
using Android.Content;
using Android.Runtime;
using Android.Views;
using Android.Widget;
using Android.OS;
using Syncfusion.SfDataGrid;
using Android.Graphics;
using Java.Lang;
using Syncfusion.Data;
using Android.Views.Animations;
using Syncfusion.SfDataGrid.DataPager;
using System.Collections.Generic;
using System.Data;
using System.Collections.ObjectModel;
using System.Threading.Tasks;
using System.Windows.Input;

namespace CustomCellSample
{
    [Activity(Label = "CustomCellSample", MainLauncher = true, Icon = "@drawable/icon")]
    public class MainActivity : Activity
    {
        SfDataGrid sfGrid;
        ViewModel viewModel;
        protected override void OnCreate(Bundle bundle)
        {
            base.OnCreate(bundle);

            LinearLayout mainLayout = new LinearLayout(this);
            mainLayout.Orientation = Orientation.Vertical;

            LinearLayout linearLayout = new LinearLayout(this);
            linearLayout.Orientation = Orientation.Horizontal;

            sfGrid = new SfDataGrid(this);
            viewModel = new ViewModel();

            sfGrid.ItemsSource = viewModel.OrdersInfo;

            sfGrid.AllowPullToRefresh = true;
            sfGrid.SelectionMode = SelectionMode.Multiple;
            sfGrid.AllowSorting = true;
            this.sfGrid.PullToRefreshCommand = new Command(ExecuteCommand);

            mainLayout.AddView(linearLayout);

            mainLayout.AddView(sfGrid);

            SetContentView(mainLayout);
        }

        private async void ExecuteCommand()
        {
            try
            {
                this.sfGrid.IsBusy = true;
                await Task.Delay(new TimeSpan(0, 0, 3));
                this.viewModel.ItemsSourceRefresh();
                this.sfGrid.IsBusy = false;
            }
            catch (Java.Lang.Exception e)
            {
                System.Diagnostics.Debug.WriteLine(e.Message);
            }
        }
    }

    public class Command : ICommand
    {
        private Action execute;
        private bool canExecute = true;

        public event EventHandler CanExecuteChanged;

        public Command(Action action)
        {
            execute = action;
        }

        public bool CanExecute(object parameter)
        {
            return canExecute;
        }

        public void Execute(object parameter)
        {
            changeCanExecute(true);
            execute.Invoke();
        }

        private void changeCanExecute(bool canExecute)
        {
            this.canExecute = canExecute;
            if (CanExecuteChanged != null)
                CanExecuteChanged(this, new EventArgs());
        }
    }

    public class FilterDefinition : IFilterDefinition
    {

        #region Field

        FilterBehavior filterBehaviour;

        ObservableCollection<FilterPredicate> filterPredicates;

        string mappingName = string.Empty;

        #endregion

        public FilterDefinition()
        {
            filterPredicates = new ObservableCollection<FilterPredicate>();
        }
        public FilterBehavior FilterBehavior
        {
            get
            {
                return filterBehaviour;
            }

            set
            {
                filterBehaviour = value;
            }
        }

        public ObservableCollection<FilterPredicate> FilterPredicates
        {
            get
            {
                return filterPredicates;
            }
        }

        public string MappingName
        {
            get
            {
                return mappingName;
            }

            set
            {
                mappingName = value;
            }
        }
    }
}

